
var YubiKey = function()
{
	var yubikey = {};
	
	yubikey.initPage = function()
	{
		// Disable YubiKey fields on extended properties tab
		Doc.element('ep.yubiKeySerial').disabled = true;
		Doc.element('ep.yubiKeyId').disabled = true;
		
		Events.addEventHandler('yubiKeySerial', 'blur', yubikey.copySerial);
		Events.doOnEnter('yubiKeyOtp', yubikey.verifyOtp);
		Buttons.addClickHandler('btnYubiKeyRemove', yubikey.removeYubiKey);
	}
	
	/* Copy serial number to extended properties tab */
	yubikey.copySerial = function()
	{
		Doc.element('ep.yubiKeySerial').value = Doc.element('yubiKeySerial').value;
	}
	
	/* Set serial number in all relevant places */
	yubikey.setSerial = function(serial)
	{
		Doc.element('yubiKeySerial').value = serial;
		Doc.element('ep.yubiKeySerial').value = serial;
	}
	
	/* Set YubiKey ID in all relevant places */
	yubikey.setYubiKeyId = function(id)
	{
		Doc.element('yubiKeyId').value = id;
		Doc.element('ep.yubiKeyId').value = id;
		Doc.element('yubiKeyId2').innerHTML = id ? id : '<i>No YubiKey</i>';
	}
	
	/*
		Remove all YubiKey values for this user.
		Switch to the non-YubiKey form
	*/
	yubikey.removeYubiKey = function()
	{
		yubikey.setSerial('');
		yubikey.setYubiKeyId('');
		
		Doc.hide('has-yubikey');
		Doc.show('no-yubikey');
		Doc.element('yubiKeyOtp').value = '';
		Doc.element('yubiKeyOtp').focus();
	}
	
	/**
		Verify that the one-time-password is ok.
	*/
	yubikey.verifyOtp = function()
	{
		var otp = Doc.element('yubiKeyOtp').value;
		Doc.hide('yubikey-error');
		
		var request = Ajax.getXmlHttpRequest();
		var response;
		var error;
		try
		{
			Doc.show('yubikey-verifying');
			var home = Data.get('yubikey-data', 'home');
			var url = home + '/YubiKey.servlet?ID='+App.getSessionId();
			url += '&cmd=Verify&otp='+encodeURIComponent(otp);
			request.open("GET", url, false);	
			request.send(null);
			response = JSON.parse(request.responseText);
			
			if (response.status != 'ok')
			{
				error = response.message;
			}
		}
		catch (e)
		{
			error = e;
		}
		finally
		{
			Doc.hide('yubikey-verifying');
		}
		
		if (error)
		{
			Doc.element('yubikey-error').innerHTML = Strings.encodeTags(error.toString ? error.toString() : error);
			Doc.show('yubikey-error');
			return;
		}
				
		var publicId = response.publicId;
		
		// Update form elements and switch to the has-YubiKey form
		yubikey.setYubiKeyId(publicId);
		Doc.show('has-yubikey');
		Doc.hide('no-yubikey');	
	}
	
	return yubikey;
}();

Doc.onLoad(YubiKey.initPage);

